@@ -4,7 +4,7 @@ import numpy as np
 import datetime as dt
 from dateutil.relativedelta import relativedelta as rd
 from .api import quantim
-from .utils import get_csv_separator
+from .utils import generate_unique_id, generate_timestamp
 
 class risk_data(quantim):
     def __init__(self, username, password, secretpool, env="pdn", api_url=None):
@@ -61,6 +61,32 @@ class risk_data(quantim):
         except:
             raise ValueError("Error: No se ha podido iniciar el proceso de límites o ya existe una ejecución en curso. Intente de nuevo en algunos minutos.")
         return resp
+    
+    def run_var(self):
+        '''
+        Run var colombia.
+        '''
+        data = {'jobname':'job_var_co'}
+        try:
+            resp = self.api_call('run_glue_job', method="post", data=data, verify=False)
+            msg = "La ejecucion del var formato 438 se ha activado exitosamente!" if resp['status']=='RUNNING' else "Error: No se ha podido iniciar el proceso de var formato 438 o ya existe una ejecución en curso. Intente de nuevo en algunos minutos."
+            print(msg)
+        except:
+            raise ValueError("Error: No se ha podido iniciar el proceso de var formato 438 o ya existe una ejecución en curso. Intente de nuevo en algunos minutos.")
+        return None
+
+    def run_var_386(self):
+        '''
+        Run var colombia.
+        '''
+        data = {'jobname':'job_var_386_co'}
+        try:
+            resp = self.api_call('run_glue_job', method="post", data=data, verify=False)
+            msg = "La ejecucion del var formato 386 se ha activado exitosamente!" if resp['status']=='RUNNING' else "Error: No se ha podido iniciar el proceso de var formato 386 o ya existe una ejecución en curso. Intente de nuevo en algunos minutos."
+            print(msg)
+        except:
+            raise ValueError("Error: No se ha podido iniciar el proceso de var formato 386 o ya existe una ejecución en curso. Intente de nuevo en algunos minutos.")
+        return None
 
     def get_portfolio(self, client_id=None, port_type=None, ref_date=None):
         '''
@@ -74,20 +100,22 @@ class risk_data(quantim):
         limits_summ =  pd.DataFrame(limits['summ'])
         return portfolio, port_dur, port_per_msg, limits_summ
     
-    def pretrade(self, portfolioName, subgroup=False, new_oper=False,  cash=False, return_detail=False, res_url=False, return_portfolio= True):
+    def pretrade(self, portfolioName, subgroup=False, cash=True, return_detail=False, res_url=False):
         '''
         Run limits lambda
         
         '''
-        if new_oper is not False:
-            cols=['type', 'secDesc1', 'counterparty', 'isin', 'assetId', 'issuerId', 'issuerLongName', 'ccy', 'duration', 'avgRating', 'ratingType', 'SIM_SECTOR', 'linkedEntity', 'quantity', 'mktValue', 'maturity']
-            if not set(cols).issubset(new_oper.columns):
-                raise ValueError(f"Las nuevas operaciones deben contener la siguiente informacion: {cols}. Por favor revisar")
-            if not set(new_oper["type"].unique()).issubset({"BUY", "SELL"}):
-                raise ValueError("La columna type unicamente recibe los valores 'BUY' o 'SELL'.")
-            new_oper=new_oper.to_dict(orient="records")
+        # if new_oper:
+        #     cols=['type', 'secDesc1', 'counterparty', 'isin', 'assetId', 'issuerId', 'issuerLongName', 'ccy', 'duration', 'avgRating',
+        #           'ratingType', 'SIM_SECTOR', 'linkedEntity', 'quantity', 'mktValue', 'maturity', 'indexRate', 'cpn', 'modDur', 'yieldToMaturity']
+        #     if not set(cols).issubset(new_oper.columns):
+        #         raise ValueError(f"Las nuevas operaciones deben contener la siguiente informacion: {cols}. Por favor revisar")
+        #     if not set(new_oper["type"].unique()).issubset({"BUY", "SELL"}):
+        #         raise ValueError("La columna type unicamente recibe los valores 'BUY' o 'SELL'.")
+        #     new_oper["issuerId"] = pd.to_numeric(new_oper["issuerId"], errors="coerce")
+        #     new_oper=new_oper.to_dict(orient="records")
         print("Ejecutando límites...")
-        data = {'portfolioName':portfolioName, 'subgroup':subgroup, 'cash':cash, 'new_oper':new_oper, 'return_detail':return_detail, 'res_url':res_url, 'return_portfolio': return_portfolio}
+        data = {'portfolioName':portfolioName, 'subgroup':subgroup, 'cash':cash, 'new_oper':None, 'return_detail':return_detail, 'res_url':res_url, 'return_portfolio': True}
         resp = self.api_call('limits', method="post", data=data, verify=False)
         if resp["status"]=="error":
             print(resp["msg"])
@@ -106,7 +134,7 @@ class risk_data(quantim):
         '''
         if not subgroup:
             subgroup = portfolioName
-        cols=['type', 'secDesc1', 'counterparty', 'isin', 'assetId', 'issuerId', 'issuerLongName', 'ccy', 'duration', 'avgRating', 'ratingType', 'SIM_SECTOR', 'linkedEntity', 'quantity', 'mktValue', 'maturity']
+        cols=['type', 'secDesc1', 'counterparty', 'isin', 'assetId', 'issuerId', 'issuerLongName', 'ccy', 'duration', 'avgRating', 'ratingType', 'SIM_SECTOR', 'linkedEntity', 'quantity', 'mktValue', 'maturity', 'indexRate', 'cpn', 'modDur', 'yieldToMaturity']
         missing_cols = set(cols) - set(new_data.columns)
         if missing_cols:
             raise ValueError(f"Las nuevas operaciones deben contener las siguientes columnas faltantes: {missing_cols}. Por favor revisar.")
@@ -115,10 +143,13 @@ class risk_data(quantim):
         if  not set(["portfolioName","subGroup"]).issubset(new_data.columns):
             new_data["portfolioName"],new_data["subGroup"]=portfolioName,subgroup
         new_data = new_data[["portfolioName","subGroup"]+cols]
-        new_data["registered"]=True
+        new_data["status"] = "created"
+        new_data["id"] = generate_unique_id()
+        new_data["timeStamp"] = generate_timestamp()
+        new_data["user"] = self.username
         new_data=new_data.to_dict(orient="records")
         fecha=dt.date.today().strftime("%Y/%m/%d")
-        data = {'bucket': 'condor-sura', 'key': f'output/pretrade/CO/trades/{fecha}/trades.csv', 'sep': sep, 'new_data': new_data}
+        data = {'bucket': 'condor-sura', 'prefix': 'output/pretrade/CO/trades', 'append_type': 'register', 'key': f'output/pretrade/CO/trades/{fecha}/trades.csv', 'sep': sep, 'new_data': new_data}
         resp = self.api_call('append_data', method="post", data=data, verify=False)
         msg=resp["msg"]
         return msg
@@ -187,8 +218,8 @@ class risk_data(quantim):
         filename = file_path.split('/')[-1]
         if filename.split('.')[-1]!='csv':
             raise ValueError('Extension must be csv. Please check file.')
-        if not np.any(np.in1d(filename.split('.')[-2], ['cupos_contrapartes', 'emisores', 'liq_min'])):
-            raise ValueError('You can only load cupos_contrapartes.csv, emisores.csv or liq_min.csv. Please check file name.')
+        if not np.any(np.in1d(filename.split('.')[-2], ['cupos_contrapartes', 'emisores', 'liq_min', 'waivers'])):
+            raise ValueError('You can only load cupos_contrapartes.csv, emisores.csv, liq_min.csv, or waivers.csv. Please check file name.')
 
 
         resp = self.upload_with_presigned_url(file_path, "condor-sura", f"inputs/pretrade/CO/{filename}")
@@ -233,7 +264,7 @@ class risk_data(quantim):
         resp = self.upload_with_presigned_url(file_path, "condor-sura", f"inputs/portfolios/buy_sell/CO/{filename}")
         return resp
 
-    def load_navs(self, file_path, country='CO'):
+    def load_inputs_bmk(self, file_path, country='CO'):
         '''
         Load fund series (NAVs).
         '''
@@ -241,10 +272,10 @@ class risk_data(quantim):
 
         if country=='CO':
             filename = file_path.split("/")[-1]
-            if filename not in ['BD_PAS.csv']:
+            if filename not in ['ret_cash.csv']:
                 raise ValueError('file name not supported.')
             else:
-                resp = self.upload_with_presigned_url(file_path, "condor-sura", f"inputs/portfolios/nav/CO/{filename}")
+                resp = self.upload_with_presigned_url(file_path, "condor-sura", f"inputs/benchmarks/asulado/{filename}")
         else:
             raise ValueError("country not supported.")
         return resp
